@@ -34,6 +34,7 @@
 #include <KShortcutsDialog>
 #include <KStandardAction>
 #include <KStandardGuiItem>
+#include <KStatusNotifierItem>
 #include <KToggleAction>
 #include <KXmlGuiWindow>
 
@@ -47,7 +48,6 @@
 #include <QScrollBar>
 #include <QStatusBar>
 #include <QStandardPaths>
-#include <QSystemTrayIcon>
 #include <QTimer>
 #include <QVBoxLayout>
 
@@ -61,7 +61,7 @@
 #include "kitenconfig.h"
 #include "resultsview.h"
 #include "searchstringinput.h"
-/* Separting Learn */
+/* Separating Learn */
 //#include "learn.h"
 
 Kiten::Kiten( QWidget *parent, const char *name )
@@ -115,8 +115,10 @@ Kiten::Kiten( QWidget *parent, const char *name )
   _optionDialog = 0;
 
   /* Start the system tray icon. */
-  _sysTrayIcon = new QSystemTrayIcon( windowIcon(), this );
-  _sysTrayIcon->show();
+  _sysTrayIcon = new KStatusNotifierItem(this);
+  _sysTrayIcon->setStandardActionsEnabled(true);
+  _sysTrayIcon->setAssociatedWidget(this);
+  _sysTrayIcon->setIconByName(QLatin1String("kiten"));
 
   /* Set things as they were (as told in the config) */
   _autoSearchToggle->setChecked( _config->autosearch() );
@@ -746,7 +748,7 @@ void Kiten::print()
 ******************************************************************************/
 
 /**
- * Given one Search Result, it addes it to the history list the logic in it
+ * Given one Search Result, it adds it to the history list the logic in it
  * exists to maintain the history list of a certain size.  Note that this method
  * does not display the EntryList it is given... so you can add something to the
  * history and display it separately.
